// Importing required modules from 'react', 'd3' and 'topojson' libraries
import { useEffect, useState } from 'react';
import { json } from 'd3';
import { feature, mesh } from 'topojson';
// Defining URL of the JSON data file
const jsonUrl =
  'https://unpkg.com/world-atlas@2.0.2/countries-50m.json';
// Custom hook to fetch and process data
export const useData = () => {
    // Initializing state to hold the fetched and processed data
  const [data, setData] = useState(null);
  // Logging the fetched and processed data for debugging purposes
  console.log(data);
 // Effect hook to fetch data from the specified URL and process it
  useEffect(() => {
     // Fetching JSON data from the specified URL using d3.json() method
    json(jsonUrl).then((topology) => {
       // Extracting the 'countries' and 'land' features from the topology object
      const { countries, land } = topology.objects;
      // Processing the data and updating the state using the setData() method
      setData({
         // Converting the 'land' feature into GeoJSON using topojson.feature() method
        land: feature(topology, land),
         // Generating the mesh of country boundaries using topojson.mesh() method
        interiors: mesh(
          topology,
          countries,
          (a, b) => a !== b
        ),
      });
    });
  }, []); // Empty dependency array to ensure the effect runs only once during component mount

  return data;
};
